==> haskell-persistent-qq-2.9.1-82-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-qq
version: 2.9.1
id: persistent-qq-2.9.1-CSAdThTS7oi1RxHjeFjmYn
key: persistent-qq-2.9.1-CSAdThTS7oi1RxHjeFjmYn
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
homepage: https://github.com/yesodweb/persistent#readme
synopsis: Provides a quasi-quoter for raw SQL for persistent
description:
    Please see README and API docs at <http://www.stackage.org/package/persistent>.
category: Database, Yesod
abi: d9e59a721ce109b9f703f215a3ae8525
exposed: True
exposed-modules:
    Database.Persist.Sql.Raw.QQ
hidden-modules: Paths_persistent_qq
import-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-qq-2.9.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-qq-2.9.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/persistent-qq-2.9.1
hs-libraries: HSpersistent-qq-2.9.1-CSAdThTS7oi1RxHjeFjmYn
depends:
    base-4.12.0.0 haskell-src-meta-0.8.2-BYEwMiPdjrnJwT3Qu9g1eB
    mtl-2.2.2 persistent-2.10.4-HbDov73WTOy2Zh0409kedg
    template-haskell-2.14.0.0 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-persistent-qq/html/persistent-qq.haddock
haddock-html: /usr/share/doc/haskell-persistent-qq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-qq-2.9.1-83-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-qq
version: 2.9.1
id: persistent-qq-2.9.1-JSnGM0DsED3Gkl0og4j8cu
key: persistent-qq-2.9.1-JSnGM0DsED3Gkl0og4j8cu
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
homepage: https://github.com/yesodweb/persistent#readme
synopsis: Provides a quasi-quoter for raw SQL for persistent
description:
    Please see README and API docs at <http://www.stackage.org/package/persistent>.
category: Database, Yesod
abi: 267dbc8adcb0275b3ed5f7de41750f66
exposed: True
exposed-modules:
    Database.Persist.Sql.Raw.QQ
hidden-modules: Paths_persistent_qq
import-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-qq-2.9.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-qq-2.9.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/persistent-qq-2.9.1
hs-libraries: HSpersistent-qq-2.9.1-JSnGM0DsED3Gkl0og4j8cu
depends:
    base-4.12.0.0 haskell-src-meta-0.8.2-BYEwMiPdjrnJwT3Qu9g1eB
    mtl-2.2.2 persistent-2.10.4-7UWClETLjrnDrKqhbTlLWd
    template-haskell-2.14.0.0 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-persistent-qq/html/persistent-qq.haddock
haddock-html: /usr/share/doc/haskell-persistent-qq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
